aboutsummaryrefslogtreecommitdiff
path: root/src/MTools/GUI
diff options
context:
space:
mode:
Diffstat (limited to 'src/MTools/GUI')
-rw-r--r--src/MTools/GUI/MTexture.pm5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/MTools/GUI/MTexture.pm b/src/MTools/GUI/MTexture.pm
index f3dff9e..12d9d5a 100644
--- a/src/MTools/GUI/MTexture.pm
+++ b/src/MTools/GUI/MTexture.pm
@@ -19,7 +19,7 @@ package MTools::GUI::MTexture;
# Permet d'appliquer un texture a un objet
# Parametres :
# * parent : pere de l'objet.
# * target : group zinc destine a contenir les images de texture
# * image_name : nom de l'image texture
use strict;
@@ -27,6 +27,7 @@ use strict;
use MTools;
use MTools::MGroup;
use MTools::GUI::MImage;
+use MTools::GUI::MClip;
use vars qw / @ISA /;
@@ -64,7 +65,7 @@ sub new {
}
}
- my $clip = $zinc -> clone ($target);
+ my $clip = clone ($target);
mconfigure ($clip, -visible => 0);
new MTools::GUI::MClip ($self, $clip);
return $self;
@@ -19,7 +19,7 @@ package MTools::GUI::MTexture;
# Parametres :
# * parent : pere de l'objet.
-# * target : group zinc destine a contenir les images de texture
+# * target : group zinc ou MTools destine a contenir les images de texture
# * image_name : nom de l'image texture
use strict;